==> jc-1.4.0.tar.gz: gnu/java/security/PolicyFile.h <==
// public final class gnu.java.security.PolicyFile

// class file dependencies
// @dep_class d45ac5c6d43c348b gnu_java_security_PolicyFile
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 22e7d19b890f754a java_security_Policy

// header file dependencies
// @dep_header java_security_Policy

#include "java/security/Policy.h"

#ifndef _JC_gnu_java_security_PolicyFile_H_
#define _JC_gnu_java_security_PolicyFile_H_

// Forward structure declarations
struct _jc_java_io_StreamTokenizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_java_net_URL$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_security_PolicyFile$sub_refs	_jc_gnu_java_security_PolicyFile$sub_refs;
typedef struct _jc_gnu_java_security_PolicyFile$sub_nonrefs	_jc_gnu_java_security_PolicyFile$sub_nonrefs;
typedef struct _jc_gnu_java_security_PolicyFile$refs	_jc_gnu_java_security_PolicyFile$refs;
typedef struct _jc_gnu_java_security_PolicyFile$nonrefs	_jc_gnu_java_security_PolicyFile$nonrefs;
typedef struct _jc_gnu_java_security_PolicyFile$object	_jc_gnu_java_security_PolicyFile$object;

typedef struct _jc_gnu_java_security_PolicyFile$fields_struct	_jc_gnu_java_security_PolicyFile$fields_struct;
typedef const struct _jc_gnu_java_security_PolicyFile$vmethods	_jc_gnu_java_security_PolicyFile$vmethods;
typedef const struct _jc_gnu_java_security_PolicyFile$vtable	_jc_gnu_java_security_PolicyFile$vtable;
typedef const struct _jc_gnu_java_security_PolicyFile$vtype	_jc_gnu_java_security_PolicyFile$vtype;

// Class fields structure
struct _jc_gnu_java_security_PolicyFile$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fPOLICY;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	jint	STATE__5fBEGIN;
	jint	STATE__5fGRANT;
	jint	STATE__5fPERMS;
	jboolean	DEBUG;
};
extern _jc_gnu_java_security_PolicyFile$fields_struct _jc_gnu_java_security_PolicyFile$class_fields;

// Constructors
extern void _jc_gnu_java_security_PolicyFile$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *);

// Virtual methods
extern struct _jc_java_security_PermissionCollection$object *_jc_gnu_java_security_PolicyFile$method$getPermissions$448009107719f384(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_security_CodeSource$object *);
extern void _jc_gnu_java_security_PolicyFile$method$parse$fc11a748e8712536(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_net_URL$object *);
extern void _jc_gnu_java_security_PolicyFile$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_PolicyFile$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$getPermissions$448009107719f384;
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$parse$fc11a748e8712536;
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$refresh$23f3d9d8f6b36945;
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_PolicyFile$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jboolean _jc_gnu_java_security_PolicyFile$method$access__240$0aec49b1cb0808ca(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_PolicyFile$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_gnu_java_security_PolicyFile$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_security_PolicyFile$method$debug$13d2368270696a9c(_jc_env *, struct _jc_java_lang_Throwable$object *);
extern void _jc_gnu_java_security_PolicyFile$method$error$cd695b31dbeb8793(_jc_env *, struct _jc_java_net_URL$object *, struct _jc_java_io_StreamTokenizer$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_PolicyFile$method$expand$8b841a776fdeb314(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_java_security_PolicyFile$vmethods {
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$448009107719f384)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_security_CodeSource$object *);
	void	(*parse$fc11a748e8712536)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_net_URL$object *);
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *);
};

// Vtable
struct _jc_gnu_java_security_PolicyFile$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Policy$vmethods	java_security_Policy;
	_jc_gnu_java_security_PolicyFile$vmethods	gnu_java_security_PolicyFile;
};

// Vtype
struct _jc_gnu_java_security_PolicyFile$vtype {
	_jc_type			type;
	_jc_gnu_java_security_PolicyFile$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_PolicyFile$sub_refs {
	struct _jc_object	*cs2pc;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_PolicyFile$refs {
    _jc_gnu_java_security_PolicyFile$sub_refs	gnu_java_security_PolicyFile;
    _jc_java_security_Policy$sub_refs	java_security_Policy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_PolicyFile$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_PolicyFile$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Policy$sub_nonrefs	java_security_Policy;
    _jc_gnu_java_security_PolicyFile$sub_nonrefs	gnu_java_security_PolicyFile;
};

// Object instance structure
struct _jc_gnu_java_security_PolicyFile$object {
	_jc_gnu_java_security_PolicyFile$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_PolicyFile$vtype	*vtype;
	_jc_gnu_java_security_PolicyFile$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_PolicyFile$vtype _jc_gnu_java_security_PolicyFile$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_PolicyFile, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_PolicyFile$class_object;

#endif	/* _JC_gnu_java_security_PolicyFile_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/PolicyFile.h <==
// public final class gnu.java.security.PolicyFile

// class file dependencies
// @dep_class d45ac5c6d43c348b gnu_java_security_PolicyFile
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 22e7d19b890f754a java_security_Policy

// header file dependencies
// @dep_header java_security_Policy

#include "java/security/Policy.h"

#ifndef _JC_gnu_java_security_PolicyFile_H_
#define _JC_gnu_java_security_PolicyFile_H_

// Forward structure declarations
struct _jc_java_io_StreamTokenizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_java_net_URL$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_security_PolicyFile$sub_refs	_jc_gnu_java_security_PolicyFile$sub_refs;
typedef struct _jc_gnu_java_security_PolicyFile$sub_nonrefs	_jc_gnu_java_security_PolicyFile$sub_nonrefs;
typedef struct _jc_gnu_java_security_PolicyFile$refs	_jc_gnu_java_security_PolicyFile$refs;
typedef struct _jc_gnu_java_security_PolicyFile$nonrefs	_jc_gnu_java_security_PolicyFile$nonrefs;
typedef struct _jc_gnu_java_security_PolicyFile$object	_jc_gnu_java_security_PolicyFile$object;

typedef struct _jc_gnu_java_security_PolicyFile$fields_struct	_jc_gnu_java_security_PolicyFile$fields_struct;
typedef const struct _jc_gnu_java_security_PolicyFile$vmethods	_jc_gnu_java_security_PolicyFile$vmethods;
typedef const struct _jc_gnu_java_security_PolicyFile$vtable	_jc_gnu_java_security_PolicyFile$vtable;
typedef const struct _jc_gnu_java_security_PolicyFile$vtype	_jc_gnu_java_security_PolicyFile$vtype;

// Class fields structure
struct _jc_gnu_java_security_PolicyFile$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fPOLICY;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	jint	STATE__5fBEGIN;
	jint	STATE__5fGRANT;
	jint	STATE__5fPERMS;
	jboolean	DEBUG;
};
extern _jc_gnu_java_security_PolicyFile$fields_struct _jc_gnu_java_security_PolicyFile$class_fields;

// Constructors
extern void _jc_gnu_java_security_PolicyFile$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_PermissionCollection$object *_jc_gnu_java_security_PolicyFile$method$getPermissions$448009107719f384(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_PolicyFile$method$parse$fc11a748e8712536(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_PolicyFile$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_PolicyFile$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$getPermissions$448009107719f384;
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$parse$fc11a748e8712536;
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$refresh$23f3d9d8f6b36945;
extern _jc_method _jc_gnu_java_security_PolicyFile$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_PolicyFile$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_security_PolicyFile$method$access__240$0aec49b1cb0808ca(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_PolicyFile$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_PolicyFile$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_PolicyFile$method$debug$13d2368270696a9c(_jc_env *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_PolicyFile$method$error$cd695b31dbeb8793(_jc_env *, struct _jc_java_net_URL$object *, struct _jc_java_io_StreamTokenizer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_PolicyFile$method$expand$8b841a776fdeb314(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_PolicyFile$vmethods {
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$448009107719f384)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
	void	(*parse$fc11a748e8712536)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_PolicyFile$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_PolicyFile$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Policy$vmethods	java_security_Policy;
	_jc_gnu_java_security_PolicyFile$vmethods	gnu_java_security_PolicyFile;
};

// Vtype
struct _jc_gnu_java_security_PolicyFile$vtype {
	_jc_type			type;
	_jc_gnu_java_security_PolicyFile$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_PolicyFile$sub_refs {
	struct _jc_object	*cs2pc;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_PolicyFile$refs {
    _jc_gnu_java_security_PolicyFile$sub_refs	gnu_java_security_PolicyFile;
    _jc_java_security_Policy$sub_refs	java_security_Policy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_PolicyFile$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_PolicyFile$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Policy$sub_nonrefs	java_security_Policy;
    _jc_gnu_java_security_PolicyFile$sub_nonrefs	gnu_java_security_PolicyFile;
};

// Object instance structure
struct _jc_gnu_java_security_PolicyFile$object {
	_jc_gnu_java_security_PolicyFile$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_PolicyFile$vtype	*vtype;
	_jc_gnu_java_security_PolicyFile$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_PolicyFile$vtype _jc_gnu_java_security_PolicyFile$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_PolicyFile, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_PolicyFile$class_object;

#endif	/* _JC_gnu_java_security_PolicyFile_H_ */
